==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/architecture/interfaces/impl/PortSetImpl.java <==
package io.ciera.tool.sql.architecture.interfaces.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.component.ComponentDefinitionSet;
import io.ciera.tool.sql.architecture.component.impl.ComponentDefinitionSetImpl;
import io.ciera.tool.sql.architecture.file.FileSet;
import io.ciera.tool.sql.architecture.file.impl.FileSetImpl;
import io.ciera.tool.sql.architecture.interfaces.IfaceSet;
import io.ciera.tool.sql.architecture.interfaces.Port;
import io.ciera.tool.sql.architecture.interfaces.PortMessageSet;
import io.ciera.tool.sql.architecture.interfaces.PortSet;
import io.ciera.tool.sql.architecture.interfaces.impl.IfaceSetImpl;
import io.ciera.tool.sql.architecture.interfaces.impl.PortMessageSetImpl;
import io.ciera.tool.sql.architecture.interfaces.impl.PortSetImpl;
import io.ciera.tool.sql.ooaofooa.component.C_POSet;
import io.ciera.tool.sql.ooaofooa.component.impl.C_POSetImpl;

import java.util.Arrays;
import java.util.List;


public class PortSetImpl extends InstanceSet<PortSet,Port> implements PortSet {

    // attributes
    @Override
    public void setName( String ref_name ) throws XtumlException {
        for ( Port port : this ) port.setName( ref_name );
    }
    @Override
    public void setPort_Id( UniqueId ref_port_Id ) throws XtumlException {
        for ( Port port : this ) port.setPort_Id( ref_port_Id );
    }
    @Override
    public void setComp_name( String ref_comp_name ) throws XtumlException {
        for ( Port port : this ) port.setComp_name( ref_comp_name );
    }
    @Override
    public void setIface_package( String ref_iface_package ) throws XtumlException {
        for ( Port port : this ) port.setIface_package( ref_iface_package );
    }
    @Override
    public void setPort_name( String m_port_name ) throws XtumlException {
        for ( Port port : this ) port.setPort_name( m_port_name );
    }
    @Override
    public void setComp_package( String ref_comp_package ) throws XtumlException {
        for ( Port port : this ) port.setComp_package( ref_comp_package );
    }
    @Override
    public void setProvider_port_package( String ref_provider_port_package ) throws XtumlException {
        for ( Port port : this ) port.setProvider_port_package( ref_provider_port_package );
    }
    @Override
    public void setProvider_port_name( String ref_provider_port_name ) throws XtumlException {
        for ( Port port : this ) port.setProvider_port_name( ref_provider_port_name );
    }
    @Override
    public void setBase_class( String m_base_class ) throws XtumlException {
        for ( Port port : this ) port.setBase_class( m_base_class );
    }
    @Override
    public void setPackage( String ref_package ) throws XtumlException {
        for ( Port port : this ) port.setPackage( ref_package );
    }
    @Override
    public void setIface_name( String ref_iface_name ) throws XtumlException {
        for ( Port port : this ) port.setIface_name( ref_iface_name );
    }
    @Override
    public void setProvider( boolean m_provider ) throws XtumlException {
        for ( Port port : this ) port.setProvider( m_provider );
    }


    // selections
    @Override
    public FileSet R401_is_a_File() throws XtumlException {
        FileSet fileset = new FileSetImpl();
        for ( Port port : this ) fileset.add( port.R401_is_a_File() );
        return fileset;
    }
    @Override
    public PortSet R4160_satisfies_provided_Port() throws XtumlException {
        PortSet portset = new PortSetImpl();
        for ( Port port : this ) portset.add( port.R4160_satisfies_provided_Port() );
        return portset;
    }
    @Override
    public PortSet R4160_satisfies_required_Port() throws XtumlException {
        PortSet portset = new PortSetImpl();
        for ( Port port : this ) portset.add( port.R4160_satisfies_required_Port() );
        return portset;
    }
    @Override
    public ComponentDefinitionSet R417_passes_messages_for_ComponentDefinition() throws XtumlException {
        ComponentDefinitionSet componentdefinitionset = new ComponentDefinitionSetImpl();
        for ( Port port : this ) componentdefinitionset.add( port.R417_passes_messages_for_ComponentDefinition() );
        return componentdefinitionset;
    }
    @Override
    public IfaceSet R418_implements_Iface() throws XtumlException {
        IfaceSet ifaceset = new IfaceSetImpl();
        for ( Port port : this ) ifaceset.add( port.R418_implements_Iface() );
        return ifaceset;
    }
    @Override
    public PortMessageSet R420_provides_implementation_for_PortMessage() throws XtumlException {
        PortMessageSet portmessageset = new PortMessageSetImpl();
        for ( Port port : this ) portmessageset.addAll( port.R420_provides_implementation_for_PortMessage() );
        return portmessageset;
    }
    @Override
    public C_POSet R422_is_transformed_from_C_PO() throws XtumlException {
        C_POSet c_poset = new C_POSetImpl();
        for ( Port port : this ) c_poset.add( port.R422_is_transformed_from_C_PO() );
        return c_poset;
    }


    @Override
    public Port nullElement() {
        return PortImpl.EMPTY_PORT;
    }

    @Override
    public PortSet emptySet() {
      return new PortSetImpl();
    }

    @Override
    public PortSet value() {
        return this;
    }

    @Override
    public List<Port> elements() {
        Port[] elements = toArray(new Port[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/architecture/interfaces/impl/PortSetImpl.java <==
package io.ciera.tool.sql.architecture.interfaces.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.component.ComponentDefinitionSet;
import io.ciera.tool.sql.architecture.component.impl.ComponentDefinitionSetImpl;
import io.ciera.tool.sql.architecture.file.FileSet;
import io.ciera.tool.sql.architecture.file.impl.FileSetImpl;
import io.ciera.tool.sql.architecture.interfaces.IfaceSet;
import io.ciera.tool.sql.architecture.interfaces.Port;
import io.ciera.tool.sql.architecture.interfaces.PortMessageSet;
import io.ciera.tool.sql.architecture.interfaces.PortSet;
import io.ciera.tool.sql.architecture.interfaces.impl.IfaceSetImpl;
import io.ciera.tool.sql.architecture.interfaces.impl.PortMessageSetImpl;
import io.ciera.tool.sql.architecture.interfaces.impl.PortSetImpl;
import io.ciera.tool.sql.ooaofooa.component.C_POSet;
import io.ciera.tool.sql.ooaofooa.component.impl.C_POSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class PortSetImpl extends InstanceSet<PortSet,Port> implements PortSet {

    public PortSetImpl() {
    }

    public PortSetImpl(Comparator<? super Port> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setProvider_port_name( String ref_provider_port_name ) throws XtumlException {
        for ( Port port : this ) port.setProvider_port_name( ref_provider_port_name );
    }
    @Override
    public void setPackage( String ref_package ) throws XtumlException {
        for ( Port port : this ) port.setPackage( ref_package );
    }
    @Override
    public void setName( String ref_name ) throws XtumlException {
        for ( Port port : this ) port.setName( ref_name );
    }
    @Override
    public void setProvider( boolean m_provider ) throws XtumlException {
        for ( Port port : this ) port.setProvider( m_provider );
    }
    @Override
    public void setPort_Id( UniqueId ref_port_Id ) throws XtumlException {
        for ( Port port : this ) port.setPort_Id( ref_port_Id );
    }
    @Override
    public void setComp_package( String ref_comp_package ) throws XtumlException {
        for ( Port port : this ) port.setComp_package( ref_comp_package );
    }
    @Override
    public void setComp_name( String ref_comp_name ) throws XtumlException {
        for ( Port port : this ) port.setComp_name( ref_comp_name );
    }
    @Override
    public void setPort_name( String m_port_name ) throws XtumlException {
        for ( Port port : this ) port.setPort_name( m_port_name );
    }
    @Override
    public void setBase_class( String m_base_class ) throws XtumlException {
        for ( Port port : this ) port.setBase_class( m_base_class );
    }
    @Override
    public void setIface_name( String ref_iface_name ) throws XtumlException {
        for ( Port port : this ) port.setIface_name( ref_iface_name );
    }
    @Override
    public void setProvider_port_package( String ref_provider_port_package ) throws XtumlException {
        for ( Port port : this ) port.setProvider_port_package( ref_provider_port_package );
    }
    @Override
    public void setIface_package( String ref_iface_package ) throws XtumlException {
        for ( Port port : this ) port.setIface_package( ref_iface_package );
    }


    // selections
    @Override
    public FileSet R401_is_a_File() throws XtumlException {
        FileSet fileset = new FileSetImpl();
        for ( Port port : this ) fileset.add( port.R401_is_a_File() );
        return fileset;
    }
    @Override
    public PortSet R4160_satisfies_provided_Port() throws XtumlException {
        PortSet portset = new PortSetImpl();
        for ( Port port : this ) portset.add( port.R4160_satisfies_provided_Port() );
        return portset;
    }
    @Override
    public PortSet R4160_satisfies_required_Port() throws XtumlException {
        PortSet portset = new PortSetImpl();
        for ( Port port : this ) portset.add( port.R4160_satisfies_required_Port() );
        return portset;
    }
    @Override
    public ComponentDefinitionSet R417_passes_messages_for_ComponentDefinition() throws XtumlException {
        ComponentDefinitionSet componentdefinitionset = new ComponentDefinitionSetImpl();
        for ( Port port : this ) componentdefinitionset.add( port.R417_passes_messages_for_ComponentDefinition() );
        return componentdefinitionset;
    }
    @Override
    public IfaceSet R418_implements_Iface() throws XtumlException {
        IfaceSet ifaceset = new IfaceSetImpl();
        for ( Port port : this ) ifaceset.add( port.R418_implements_Iface() );
        return ifaceset;
    }
    @Override
    public PortMessageSet R420_provides_implementation_for_PortMessage() throws XtumlException {
        PortMessageSet portmessageset = new PortMessageSetImpl();
        for ( Port port : this ) portmessageset.addAll( port.R420_provides_implementation_for_PortMessage() );
        return portmessageset;
    }
    @Override
    public C_POSet R422_is_transformed_from_C_PO() throws XtumlException {
        C_POSet c_poset = new C_POSetImpl();
        for ( Port port : this ) c_poset.add( port.R422_is_transformed_from_C_PO() );
        return c_poset;
    }


    @Override
    public Port nullElement() {
        return PortImpl.EMPTY_PORT;
    }

    @Override
    public PortSet emptySet() {
      return new PortSetImpl();
    }

    @Override
    public PortSet emptySet(Comparator<? super Port> comp) {
      return new PortSetImpl(comp);
    }

    @Override
    public PortSet value() {
        return this;
    }

    @Override
    public List<Port> elements() {
        Port[] elements = toArray(new Port[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
